/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.gwt.wysiwyg.client.plugin.image;

import org.xwiki.gwt.dom.client.JavaScriptObject;
import org.xwiki.gwt.user.client.ui.rta.cmd.internal.AbstractInsertElementExecutable.ConfigJSONParser;
import org.xwiki.gwt.wysiwyg.client.plugin.image.ImageConfig.ImageAlignment;

/**
 * Creates {@link ImageConfig} instances from JSON.
 * 
 * @version $Id: afd3a2bdb1f912f4d2d0c7804fea32ceef83dab1 $
 */
public class ImageConfigJSONParser implements ConfigJSONParser<ImageConfig>
{
    /**
     * {@inheritDoc}
     * 
     * @see ConfigJSONParser#parse(String)
     */
    public ImageConfig parse(String json)
    {
        JavaScriptObject jsObj = JavaScriptObject.fromJson(json);
        ImageConfig imageConfig = new ImageConfig();
        imageConfig.setReference((String) jsObj.get("reference"));
        imageConfig.setUrl((String) jsObj.get("url"));
        imageConfig.setWidth((String) jsObj.get("width"));
        imageConfig.setHeight((String) jsObj.get("height"));
        imageConfig.setAltText((String) jsObj.get("alttext"));
        String foundAlignment = (String) jsObj.get("alignment");
        if (foundAlignment != null) {
            imageConfig.setAlignment(ImageAlignment.valueOf(foundAlignment));
        }
        return imageConfig;
    }
}
